# AIDungeon2

Read more about AIDungeon2 and how it was built [here](https://pcc.cs.byu.edu/2019/11/21/ai-dungeon-2-creating-infinitely-generated-text-adventures-with-deep-learning-language-models/).

Play the game in Colab [here](http://www.aidungeon.io).

To play the game locally you need a beefy GPU ~12 GB and CUDA installed.
```
git clone https://github.com/nickwalton/AIDungeon/
cd AIDungeon
./install.sh
python play.py
```
